@@ -17,6 +17,7 @@ setAs("dspMatrix", "lspMatrix", function(from) d2l_Matrix(from, "dspMatrix"))
 setAs("dtrMatrix", "ltrMatrix", function(from) d2l_Matrix(from, "dtrMatrix"))
 setAs("dtpMatrix", "ltpMatrix", function(from) d2l_Matrix(from, "dtpMatrix"))
 
+if(FALSE) ## FIXME, this fails for ("dtpMatrix" -> "CsparseMatrix") where .dense2C() works
 setAs("ddenseMatrix", "CsparseMatrix",
       function(from) {
 	  if (class(from) != "dgeMatrix") # don't lose symmetry/triangularity/...
@@ -89,7 +90,7 @@ setMethod("solve", signature(a = "ddenseMatrix", b = .b),
 	  function(a, b, ...) solve(as(a, "dgeMatrix"), Matrix(b)))
 
 setMethod("lu", signature(x = "ddenseMatrix"),
-          function(x, ...) lu(as(x, "dgeMatrix")))
+	  function(x, ...) lu(as(x, "dgeMatrix"), ...))
 
 setMethod("chol", signature(x = "ddenseMatrix"), cholMat)
 
